function [Absorption sigma_diel sigma_n sigma_trans nh3PeakFa nh3Aysmma ArAysmma Pressure P_2sigma Temperature T_2sigma Nmeasured Nmeasured_2sigma NmeasuredAr NmeasuredAr_2sigma TAr PAr]=Acalc(R,ptag,device,filetag,sync,old,additionaltrans,S,rconf,hconf,TEmodes)
% main function for calculating opacity, refractivity, temperature,
% pressure, frequency and their corresponding uncertainties
% Requires minor modifications for processing H2O data

% R = resonance number
% ptag = filename extension string for each pressure measurement
% device = device that took the data (0 for E5071C Network Analyzer [not obtained until 1/31/07], 1 for
%       8564E Spectrum Analyzer, 2 for 40 GHz Network Analyzer, 3 for E5071B Network Analyzer, borrowed 
%       from Dr. Durgin's lab prior to aquiring E5071C)
% filetag = additional tag for file beyond ptag (_0, _2, _NA, etc.)
% sync = 1 for calculating based on synchronized measurements.  Default value is 0.
% old = 1 for measurements before 7/2006 when numswp naming convention changed.  Use a value of 0.

% additionaltrans is used for cases where another source of transmissivity
% loss is included in the transmissivity measurements, such as using a 
% directional coupler at W-band.  The value should be in dB, if not used, set to 0.

% S is set to 21 for using S21 in network analyzer measurements or 12 for
% using S12.  If a network analyzer is not used, the S value is meaningless.

% rconf and hconf are used to define the dimensions of the resonators.  See
% section 3.4.2 of thesis.

% TEmodes is a 1 by 3 vector of the modes [N M L] of the given resonance.
% The values should be 0 for k/ka-band Fabry-Perot measurements.

c=299792.458; % speed of light in km/s
dbconv=10*log10(exp(1));
Rstr=num2str(R);

if device==1    % deconvolve effect of transmissivity on higher frequency (spectrum analyzer) measurements
    Tran=transdeconvolve(Rstr,ptag,filetag,device,sync,old);
    Tran0=zeros(601,1);
elseif device==2  % deconvolve effect of transmissivity on higher frequency (40 GHz network analyzer) measurements
    Tran=transdeconvolve(Rstr,ptag,filetag,device,sync,old);
    Tran0=zeros(401,1);
else        % no deconvolution of transmissivity used for network analyzer below 8.5 GHz
    Tran=zeros(1601,1);
    Tran0=zeros(1601,1);
end

if (device==0 || device==2 || device==3)&& S==21 %use NAprocess algorithm for S21
vac1file=strcat(Rstr, '_vac1');
load(vac1file, 'S21', 'numswp', 'faxis','T1','T2')
[V1BW3dBa V1BW3dBe V1PeakFa V1PeakFe V1Qa V1Qe V1Levela V1Levele V1Asymma V1Asymme]=NAprocess(S21,numswp,faxis,Tran0);
V1T=273.15+(T1+T2)/2;
vac2file=strcat(Rstr, '_vac2');
load(vac2file, 'S21', 'numswp', 'faxis','T1','T2')
[V2BW3dBa V2BW3dBe V2PeakFa V2PeakFe V2Qa V2Qe V2Levela V2Levele V2Asymma V2Asymme]=NAprocess(S21,numswp,faxis,Tran0);
V2T=273.15+(T1+T2)/2;
vac3file=strcat(Rstr, '_vac3');
load(vac3file, 'S21', 'numswp', 'faxis','T1','T2')
[V3BW3dBa V3BW3dBe V3PeakFa V3PeakFe V3Qa V3Qe V3Levela V3Levele V3Asymma V3Asymme]=NAprocess(S21,numswp,faxis,Tran0);
V3T=273.15+(T1+T2)/2;

Ar_file=strcat(Rstr, '_Ar_',ptag,filetag);
load(Ar_file, 'S21', 'numswp', 'faxis','time','T1','T2','P1','P2')
[ArBW3dBa ArBW3dBe ArPeakFa ArPeakFe ArQa ArQe ArLevela ArLevele ArAysmma ArAysmme]=NAprocess(S21,numswp,faxis,Tran);
TAr=(T1+T2)/2+273.15;
PAr=1+(P1+P2)/2;

nh3_file=strcat(Rstr, '_nh3_',ptag,filetag);
load(nh3_file, 'S21', 'numswp', 'faxis','T1','T2','P1','P2')
Span=(faxis(length(faxis))-faxis(1));
Gasnumswp=numswp;
[nh3BW3dBa nh3BW3dBe nh3PeakFa nh3PeakFe nh3Qa nh3Qe nh3Levela nh3Levele nh3Aysmma nh3Aysmme]=NAprocess(S21,numswp,faxis,Tran);

Trans1_file=strcat(Rstr, '_Trans1_',ptag,filetag);
load(Trans1_file, 'S21', 'numswp', 'faxis')
[transa(1) transe(1)]=trancalNA(S21,numswp, faxis, nh3PeakFa);
Trans2_file=strcat(Rstr, '_Trans2_',ptag,filetag);
load(Trans2_file, 'S21', 'numswp', 'faxis')
[transa(2) transe(2)]=trancalNA(S21,numswp, faxis, nh3PeakFa);
Trans3_file=strcat(Rstr, '_Trans3_',ptag,filetag);
load(Trans3_file, 'S21', 'numswp', 'faxis')
[transa(3) transe(3)]=trancalNA(S21,numswp, faxis, nh3PeakFa);

elseif (device==0 || device==2 || device==3)&&S==12 %use NAprocess algorithm for S12
vac1file=strcat(Rstr, '_vac1');
load(vac1file, 'S12', 'numswp', 'faxis','T1','T2')
[V1BW3dBa V1BW3dBe V1PeakFa V1PeakFe V1Qa V1Qe V1Levela V1Levele V1Asymma V1Asymme]=NAprocess(S12,numswp,faxis,Tran0);
V1T=273.15+(T1+T2)/2;
vac2file=strcat(Rstr, '_vac2');
load(vac2file, 'S12', 'numswp', 'faxis','T1','T2')
[V2BW3dBa V2BW3dBe V2PeakFa V2PeakFe V2Qa V2Qe V2Levela V2Levele V2Asymma V2Asymme]=NAprocess(S12,numswp,faxis,Tran0);
V2T=273.15+(T1+T2)/2;
vac3file=strcat(Rstr, '_vac3');
load(vac3file, 'S12', 'numswp', 'faxis','T1','T2')
[V3BW3dBa V3BW3dBe V3PeakFa V3PeakFe V3Qa V3Qe V3Levela V3Levele V3Asymma V3Asymme]=NAprocess(S12,numswp,faxis,Tran0);
V3T=273.15+(T1+T2)/2;

Ar_file=strcat(Rstr, '_Ar_',ptag,filetag);
load(Ar_file, 'S12', 'numswp', 'faxis','time','T1','T2','P1','P2')
[ArBW3dBa ArBW3dBe ArPeakFa ArPeakFe ArQa ArQe ArLevela ArLevele ArAysmma ArAysmme]=NAprocess(S12,numswp,faxis,Tran);
TAr=(T1+T2)/2+273.15;
PAr=1+(P1+P2)/2;

nh3_file=strcat(Rstr, '_nh3_',ptag,filetag);
load(nh3_file, 'S12', 'numswp', 'faxis','T1','T2','P1','P2')
Span=(faxis(length(faxis))-faxis(1));
Gasnumswp=numswp;
[nh3BW3dBa nh3BW3dBe nh3PeakFa nh3PeakFe nh3Qa nh3Qe nh3Levela nh3Levele nh3Aysmma nh3Aysmme]=NAprocess(S12,numswp,faxis,Tran);

Trans1_file=strcat(Rstr, '_Trans1_',ptag,filetag);
load(Trans1_file, 'S12', 'numswp', 'faxis')
[transa(1) transe(1)]=trancalNA(S12,numswp, faxis, nh3PeakFa);
Trans2_file=strcat(Rstr, '_Trans2_',ptag,filetag);
load(Trans2_file, 'S12', 'numswp', 'faxis')
[transa(2) transe(2)]=trancalNA(S12,numswp, faxis, nh3PeakFa);
Trans3_file=strcat(Rstr, '_Trans3_',ptag,filetag);
load(Trans3_file, 'S12', 'numswp', 'faxis')
[transa(3) transe(3)]=trancalNA(S12,numswp, faxis, nh3PeakFa);

elseif device==1 && sync==0 && old==0   % use resprocessSA for spectrum analyzer measurements
vac1file =strcat(Rstr, '_vac1');
load(vac1file, 'B', 'numswp2', 'freq','RBW','T1','T2')
[V1BW3dBa V1BW3dBe V1PeakFa V1PeakFe V1Qa V1Qe V1Levela V1Levele V1Asymma V1Asymme]=resprocessSA(B,numswp2,freq,RBW,Tran0);
V1T=273.15+(T1+T2)/2;
vac2file =strcat(Rstr, '_vac2');
load(vac2file, 'B', 'numswp2', 'freq','RBW','T1','T2')
VacSpan=(freq(601)-freq(1));
VacRBW=RBW;
[V2BW3dBa V2BW3dBe V2PeakFa V2PeakFe V2Qa V2Qe V2Levela V2Levele V2Aysmma V2Asymme]=resprocessSA(B,numswp2,freq,RBW,Tran0);
V2T=273.15+(T1+T2)/2;
vac3file =strcat(Rstr, '_vac3');
load(vac3file, 'B', 'numswp2', 'freq','RBW','T1','T2')
[V3BW3dBa V3BW3dBe V3PeakFa V3PeakFe V3Qa V3Qe V3Levela V3Levele V3Aysmma V3Aysmme]=resprocessSA(B,numswp2,freq,RBW,Tran0);
V3T=273.15+(T1+T2)/2;

Ar_file =strcat(Rstr, '_Ar_',ptag,filetag);
load(Ar_file, 'B', 'numswp2', 'freq','RBW','time','T1','T2','P1','P2')
[ArBW3dBa ArBW3dBe ArPeakFa ArPeakFe ArQa ArQe ArLevela ArLevele ArAysmma ArAysmme]=resprocessSA(B,numswp2,freq,RBW,Tran);
TAr=(T1+T2)/2+273.15;
PAr=1+(P1+P2)/2;

nh3_file =strcat(Rstr, '_nh3_',ptag,filetag);
load(nh3_file, 'B', 'numswp2', 'freq','RBW','T1','T2','P1','P2')
Span=(freq(601)-freq(1));
GasRBW=RBW;
Gasnumswp=numswp2;
[nh3BW3dBa nh3BW3dBe nh3PeakFa nh3PeakFe nh3Qa nh3Qe nh3Levela nh3Levele nh3Aysmma nh3Aysmme]=resprocessSA(B,numswp2,freq,RBW,Tran);

Trans1_file =strcat(Rstr, '_Trans1_',ptag,filetag);
load(Trans1_file, 'B', 'numswp2', 'freq')
[transa(1) transe(1)]=trancal(B,numswp2, freq, nh3PeakFa);
Trans2_file =strcat(Rstr, '_Trans2_',ptag,filetag);
load(Trans2_file, 'B', 'numswp2', 'freq')
[transa(2) transe(2)]=trancal(B,numswp2, freq, nh3PeakFa);
Trans3_file =strcat(Rstr, '_Trans3_',ptag,filetag);
load(Trans3_file, 'B', 'numswp2', 'freq')
[transa(3) transe(3)]=trancal(B,numswp2, freq, nh3PeakFa);
    
elseif device==1 && sync==0 && old==1   % old spectrum analyzer measurement data storage format
vac1file =strcat(Rstr, '_vac1');
load(vac1file, 'B', 'numswp', 'freq','RBW','T1','T2')
[V1BW3dBa V1BW3dBe V1PeakFa V1PeakFe V1Qa V1Qe V1Levela V1Levele V1Asymma V1Asymme]=resprocessSA(B,numswp,freq,RBW,Tran0);
V1T=273.15+(T1+T2)/2;
vac2file =strcat(Rstr, '_vac2');
load(vac2file, 'B', 'numswp', 'freq','RBW','T1','T2')
VacSpan=(freq(601)-freq(1));
VacRBW=RBW;
[V2BW3dBa V2BW3dBe V2PeakFa V2PeakFe V2Qa V2Qe V2Levela V2Levele V2Aysmma V2Asymme]=resprocessSA(B,numswp,freq,RBW,Tran0);
V2T=273.15+(T1+T2)/2;
vac3file =strcat(Rstr, '_vac3');
load(vac3file, 'B', 'numswp', 'freq','RBW','T1','T2')
[V3BW3dBa V3BW3dBe V3PeakFa V3PeakFe V3Qa V3Qe V3Levela V3Levele V3Aysmma V3Aysmme]=resprocessSA(B,numswp,freq,RBW,Tran0);
V3T=273.15+(T1+T2)/2;

Ar_file =strcat(Rstr, '_Ar_',ptag,filetag);
load(Ar_file, 'B', 'numswp', 'freq','RBW','time','T1','T2','P1','P2')
[ArBW3dBa ArBW3dBe ArPeakFa ArPeakFe ArQa ArQe ArLevela ArLevele ArAysmma ArAysmme]=resprocessSA(B,numswp,freq,RBW,Tran);
TAr=(T1+T2)/2+273.15;
PAr=1+(P1+P2)/2;

nh3_file =strcat(Rstr, '_nh3_',ptag,filetag);
load(nh3_file, 'B', 'numswp', 'freq','RBW','T1','T2','P1','P2')
Span=(freq(601)-freq(1));
GasRBW=RBW;
Gasnumswp=numswp;
[nh3BW3dBa nh3BW3dBe nh3PeakFa nh3PeakFe nh3Qa nh3Qe nh3Levela nh3Levele nh3Aysmma nh3Aysmme]=resprocessSA(B,numswp,freq,RBW,Tran);

Trans1_file =strcat(Rstr, '_Trans1_',ptag,filetag);
load(Trans1_file, 'B', 'numswp', 'freq')
[transa(1) transe(1)]=trancal(B,numswp, freq, nh3PeakFa);
Trans2_file =strcat(Rstr, '_Trans2_',ptag,filetag);
load(Trans2_file, 'B', 'numswp', 'freq')
[transa(2) transe(2)]=trancal(B,numswp, freq, nh3PeakFa);
Trans3_file =strcat(Rstr, '_Trans3_',ptag,filetag);
load(Trans3_file, 'B', 'numswp', 'freq')
[transa(3) transe(3)]=trancal(B,numswp, freq, nh3PeakFa);

elseif device==1 && sync==1     % use resprocessSAsync for synchronized spectrum analyzer measurements
vac1file =strcat(Rstr, '_vac1');
load(vac1file, 'C', 'numswp', 'freq','RBW','T1','T2')
[V1BW3dBa V1BW3dBe V1PeakFa V1PeakFe V1Qa V1Qe V1Levela V1Levele V1Asymma V1Asymme]=resprocessSAsync(C,numswp,freq,RBW,Tran0);
V1T=273.15+(T1+T2)/2;
vac2file =strcat(Rstr, '_vac2');
load(vac2file, 'C', 'numswp', 'freq','RBW','RBW2','T1','T2')
VacSpan=(freq(601)-freq(1));
VacRBW=RBW2;
[V2BW3dBa V2BW3dBe V2PeakFa V2PeakFe V2Qa V2Qe V2Levela V2Levele V2Aysmma V2Asymme]=resprocessSAsync(C,numswp,freq,RBW,Tran0);
V2T=273.15+(T1+T2)/2;
vac3file =strcat(Rstr, '_vac3');
load(vac3file, 'C', 'numswp', 'freq','RBW','T1','T2')
[V3BW3dBa V3BW3dBe V3PeakFa V3PeakFe V3Qa V3Qe V3Levela V3Levele V3Aysmma V3Aysmme]=resprocessSAsync(C,numswp,freq,RBW,Tran0);
V3T=273.15+(T1+T2)/2;

Ar_file =strcat(Rstr, '_Ar_',ptag,filetag);
load(Ar_file, 'C', 'numswp', 'freq','RBW','time','T1','T2','P1','P2')
[ArBW3dBa ArBW3dBe ArPeakFa ArPeakFe ArQa ArQe ArLevela ArLevele ArAysmma ArAysmme]=resprocessSAsync(C,numswp,freq,RBW,Tran);

TAr=(T1+T2)/2+273.15;
PAr=1+(P1+P2)/2;

nh3_file =strcat(Rstr, '_nh3_',ptag,filetag);
load(nh3_file, 'C', 'numswp', 'freq','RBW','RBW2','T1','T2','P1','P2')
Span=(freq(601)-freq(1));
GasRBW=RBW2;
Gasnumswp=numswp;
[nh3BW3dBa nh3BW3dBe nh3PeakFa nh3PeakFe nh3Qa nh3Qe nh3Levela nh3Levele nh3Aysmma nh3Aysmme]=resprocessSAsync(C,numswp,freq,RBW,Tran);

Trans1_file =strcat(Rstr, '_Trans1_',ptag,filetag);
load(Trans1_file, 'C', 'numswp', 'freq')
[transa(1) transe(1)]=trancalsync(C,numswp, freq, nh3PeakFa);
Trans2_file =strcat(Rstr, '_Trans2_',ptag,filetag);
load(Trans2_file, 'C', 'numswp', 'freq')
[transa(2) transe(2)]=trancalsync(C,numswp, freq, nh3PeakFa);
Trans3_file =strcat(Rstr, '_Trans3_',ptag,filetag);
load(Trans3_file, 'C', 'numswp', 'freq')
[transa(3) transe(3)]=trancalsync(C,numswp, freq, nh3PeakFa);

else
    disp('incorrect input')
end
    % calculate effect of transmissivity of cables/waveguides internal to
    % the pressure vessels
    load cabletrans
if rconf==1 && device~=1  % large resonator measured with one of the network analyzers
    addtrans=ppval(pplargerestrans,faxis((length(faxis)-1)/2+1));
elseif rconf==1&&device==1  % large resonator measured with the spectrum analyzer
    addtrans=ppval(pplargerestrans,freq((length(freq)-1)/2+1));
elseif rconf>1 && device~=1
    addtrans=ppval(ppsmallrestrans,faxis((length(faxis)-1)/2+1));
elseif rconf>1 && device==1
    addtrans=ppval(ppsmallrestrans,freq((length(freq)-1)/2+1));
elseif rconf==0 %Ka-band Fabry-Perot resonator

    % manually measured loss from waveguides in Ka-band Fabry-Perot resonator for each resonance
    if R==1||R==85
        addtrans=7;
    elseif R==2||R==86
        addtrans=4.5;
    elseif R==3||R==87
        addtrans=5.5;
    elseif R==4||R==88
        addtrans=2;
    elseif R==5||R==89
        addtrans=2;
    elseif R==6||R==90
        addtrans=3;
    elseif R==7||R==91
        addtrans=3.5;
    elseif R==8
        addtrans=14.5;
    elseif R==9
        addtrans=1.5;
    elseif R==10
        addtrans=5.2;
    elseif R==11
        addtrans=3.5;
    elseif R==12
        addtrans=2;
    elseif R==13  
        addtrans=2.3;
    elseif R==14
        addtrans=3.1;
    elseif R==15         
        addtrans=3.5;    
end    
end

trans=(transa(1)+transa(2)+transa(3))/3;
% calculate uncertainty in transmissivity including output power from swept signal generator
if device==1 && V2PeakFa>20e9
    transsig=sqrt((4.303/sqrt(3)*std([transa(1) transa(2) transa(3)]))^2+(0.8)^2); % 0.8 dB is 2-sigma uncertainy of amplitude in Sig Gen up to 40 Ghz
elseif device==1 && V2PeakFa<=20e9
    transsig=sqrt((4.303/sqrt(3)*std([transa(1) transa(2) transa(3)]))^2+(2/3)^2); % 2/3 dB is 2-sigma uncertainy of amplitude in Sig Gen up to 20 Ghz
else
    transsig=4.303/sqrt(3)*std([transa(1) transa(2) transa(3)]);
end
transsig=sqrt(transsig^2+0.25^2); % additional 0.25dB transmissivity uncertainties from internal cables

InsLossLoaded=nh3Levela-(trans+additionaltrans-addtrans); % Insertion Loss in dB
TransLoaded=10^(InsLossLoaded/10); % Transmissivity (no units)
InsLossUnloaded=ArLevela-(trans+additionaltrans-addtrans); % Insertion Loss in dB
TransUnloaded=10^(InsLossUnloaded/10); % Transmissivity (no units)

transsigmal1=10^((transsig+InsLossLoaded)/10);
transsigmal2=10^((-transsig+InsLossLoaded)/10);
transsigmal=abs(transsigmal1-transsigmal2)/2;
transsigmau1=10^((transsig+InsLossUnloaded)/10);
transsigmau2=10^((-transsig+InsLossUnloaded)/10);
transsigmau=abs(transsigmau1-transsigmau2)/2;

lambda=c/nh3PeakFa;
for cnt=1:3
    % calculate opacity (dB/km) for each 3-dB bandwidth (regular, twice
    % high half, twice low half)
Absorption(cnt)=dbconv*2*pi/lambda*((1-sqrt(TransLoaded))/nh3Qa(cnt)-(1-sqrt(TransUnloaded))/ArQa(cnt));
end
R
for cnt=1:1 % can be modified to iterate for both of the asymmetry calculations
if device==0||device==2||device==3
sigma_n(cnt)=insterror(nh3Qa(cnt),ArQa(cnt),nh3BW3dBe(cnt),ArBW3dBe(cnt),1,1,nh3PeakFa,ArPeakFa,TransLoaded,TransUnloaded,nh3BW3dBa(cnt),Gasnumswp,time,device);
elseif sync==0
sigma_n(cnt)=insterror(nh3Qa(cnt),ArQa(cnt),nh3BW3dBe(cnt),ArBW3dBe(cnt),Span,RBW,nh3PeakFa,ArPeakFa,TransLoaded,TransUnloaded,nh3BW3dBa(cnt),Gasnumswp,time,device);
elseif sync==1
sigma_n(cnt)=insterror(nh3Qa(cnt),ArQa(cnt),nh3BW3dBe(cnt),ArBW3dBe(cnt),Span,RBW2,nh3PeakFa,ArPeakFa,TransLoaded,TransUnloaded,nh3BW3dBa(cnt),Gasnumswp,time,device);
end

dQdF(cnt)=max(abs([(V1Qa(cnt)-ArQa(cnt))/(V1PeakFa-ArPeakFa) (V2Qa(cnt)-ArQa(cnt))/(V2PeakFa-ArPeakFa) (V3Qa(cnt)-ArQa(cnt))/(V3PeakFa-ArPeakFa)]));
dQ(cnt)=dQdF(cnt)*abs(nh3PeakFa-ArPeakFa);
dA1(cnt)=dbconv*2*pi/lambda*((1-sqrt(TransLoaded))/(nh3Qa(cnt))-(1-sqrt(TransUnloaded))/(ArQa(cnt)+dQ(cnt)));
dA2(cnt)=dbconv*2*pi/lambda*((1-sqrt(TransLoaded))/(nh3Qa(cnt))-(1-sqrt(TransUnloaded))/(ArQa(cnt)-dQ(cnt)));
sigma_diel(cnt)=abs(dA1(cnt)-dA2(cnt)); % 2-sigma errorbar

sigma_trans(cnt)=dbconv*pi/lambda*abs(((sqrt(TransLoaded+transsigmal)-sqrt(TransLoaded-transsigmal))/nh3Qa(cnt)-(sqrt(TransUnloaded-transsigmau)-sqrt(TransUnloaded+transsigmau))/ArQa(cnt))); % 2-sigma errorbar
drawnow
end

Pressure=1+(P1+P2)/2;

Temperature=273.15+(T1+T2)/2; % average readings and convert Celcius to Kelvin
if Pressure<1.05 && etime(time,[2007 5 23 0 0 0])<0 % before DPG7000 vac/15 acquired
    P_2sigma=0.002; % vacuum gauge uncertainty, including temperature flucuation with calibration
elseif Pressure<(1+15/14.504) && etime(time,[2007 5 23 0 0 0])>0 % date of start of usage of 15psi DPG 7000
    P_2sigma=0.0005*(15/14.504+1)*2/3; % pressure gauge uncertainty (DPG 7000, vac/15psi)
elseif etime(time,[2007 5 23 0 0 0])<0
    P_2sigma=0.0005*300/14.504*2/3+0.010; % pressure gauge uncertainty (DPG 7000, 300psi), assuming manufacturer spec is 3-sigma
    % plus uncertainty due to not recording ambient air pressure effect on gauge readings
else
    P_2sigma=0.0005*300/14.504*2/3;
end

if (T1+T2)/2 < 0
    T_2sigma=sqrt((abs(0.003*(T1+T2)/2)+0.6)^2+(max([1 abs(.0075*(T1+T2)/2)]))^2)*2/3; %uncertainty from gauge + uncertainty from T-type thermocouple, assuming manufacturer spec is 3-sigma
else
    T_2sigma=sqrt((abs(0.001*(T1+T2)/2)+0.6)^2+(max([1 abs(.0075*(T1+T2)/2)]))^2)*2/3; %uncertainty from gauge + uncertainty from T-type thermocouple, assuming manufacturer spec is 3-sigma
end

% the rest of the code calculates the refractivity and its uncertainties,
% see section 3.4.2 of the Hanley thesis

if device==0||device==2
    yrs = etime(time,[2007 1 7 0 0 0])/(60*60*24*365.24); % years since E5071C network analyzer calibrated (1/7/07)
    sigma_o_vac=(5e-8+5e-7*yrs)*2/3*V2PeakFa; %+/- 0.05ppm for network analyzer for measurements made after 2/1/07 (new network analyzer);
    sigma_o_gas=(5e-8+5e-7*yrs)*2/3*nh3PeakFa; %+/- 0.05ppm for network analyzer
elseif device==3
    yrs = etime(time,[2005 6 1 0 0 0])/(60*60*24*365.24); % years since E5071B network analyzer calibrated (6/1/05)   
    sigma_o_vac=(5e-6+5e-7*yrs)*2/3*V2PeakFa; %+/- 5ppm for network analyzer, but using 10MHz reference from newer NA
    sigma_o_gas=(5e-6+5e-7*yrs)*2/3*nh3PeakFa; %+/- 5ppm for network analyzer
else
    yrs = etime(time,[2005 12 5 0 0 0])/(60*60*24*365.24); % years since 8564E spectrum analyzer calibrated (12/5/05)

    if V2PeakFa < 6.4e9
        N=1;
    elseif V2PeakFa < 13.2e9
        N=2;
    elseif V2PeakFa < 31e9
        N=4;
    elseif V2PeakFa < 40.05e9
        N=8;
    else
        N=18;
    end
if VacSpan > 2e6*N
    sigma_o_vac = ((yrs*1e-7+3.2e-8)*V2PeakFa + .15*VacRBW + .05*VacSpan + 10)*2/3; %Hz for HP8564E
else
    sigma_o_vac = ((yrs*1e-7+3.2e-8)*V2PeakFa + .15*VacRBW + .01*VacSpan + 10)*2/3;
end
    if nh3PeakFa < 6.4e9
        N=1;
    elseif nh3PeakFa < 13.2e9
        N=2;
    elseif nh3PeakFa < 31e9
        N=4;
    elseif nh3PeakFa < 40.05e9
        N=8;
    else
        N=18;
    end
if Span > 2e6*N
    sigma_o_gas = ((yrs*1e-7+3.2e-8)*nh3PeakFa + .15*GasRBW + .05*Span + 10)*2/3; %Hz for HP8564E
else
    sigma_o_gas = ((yrs*1e-7+3.2e-8)*nh3PeakFa + .15*GasRBW + .01*Span + 10)*2/3;
end
end

if Gasnumswp==5
    confc=2.776;
elseif Gasnumswp==3
    confc=4.303;
elseif Gasnumswp==7
    confc=2.447;    
elseif Gasnumswp==10
    confc=2.262;
elseif Gasnumswp==30
    confc=2.045; 
end


Fvac=(V1PeakFa+V2PeakFa+V3PeakFa)/3;
Tvac=(V1T+V2T+V3T)/3;

N=TEmodes(R,1);
M=TEmodes(R,2);
L=TEmodes(R,3);

if rconf==1  % large cavity resonator
    a=[13.06513 1.2895e-4 1.398e-7];
    Tdifferential=-0.5;
    if hconf==1
        b=[25.31654 3.6444e-4];
    elseif hconf==2
        b=[25.63375 4.1267e-4];
    elseif hconf==3
        b=[25.60325 4.5633e-4];
    elseif hconf==4
        b=[25.61695 4.6535e-4];
    end
elseif rconf==2     % small cavity resonator
    a=[2.47258 3.3034e-5 1.522e-8];
    Tdifferential=-0.3;
    if hconf==5
        b=[4.81633 7.9129e-5];
    elseif hconf==7
        b=[5.00384 7.9870e-5];
    end
elseif rconf==3     % small cavity resonator   
    Tdifferential=-0.3;
    a=[2.47287 3.4841e-5 1.040e-8];
    if hconf==6
        b=[5.25032 1.0786e-4];
    end
else    % K/Ka-band Fabry-Perot
    Tdifferential=-0.0;
end

%table of relevant Bessel function derivative zeros 
p=[3.83170597	7.01558667	10.17346814	13.32369194	16.47063005	19.61585851	22.76008438	25.90367209	29.04682853	32.18967991	35.33230755	38.47476623	41.61709421	44.75931900	47.90146089	51.04353518;
1.84118365	5.33144267	8.53631625	11.70600480	14.86358852	18.01552776	21.16436972	24.31132674	27.45705046	30.60192283	33.74618277	36.88998730	40.03344393	43.17662886	46.31959745	49.46239102;
3.05423681	6.70613308	9.96946772	13.17037076	16.34752217	19.51291266	22.67158165	25.82603703	28.97767266	32.12732692	35.27553495	38.42265472	41.56893482	44.71455342	47.85964149	51.00429755;
4.20118882	8.01523651	11.34592419	14.58584818	17.78874774	20.97247683	24.14489733	27.31005783	30.47026868	33.62694908	36.78102057	39.93310852	43.08365254	46.23297098	49.38129997	52.52881863;
5.31755304	9.28239617	12.68190830	15.96410698	19.19602870	22.40103216	25.58975957	28.76783609	31.93853923	35.10391655	38.26531687	41.42366638	44.57962303	47.73366740	50.88615905	54.03737230;
6.41561615	10.51986075	13.98718852	17.31284239	20.57551442	23.80358139	27.01030778	30.20284896	33.38544379	36.56077759	39.73064011	42.89627306	46.05856616	49.21817450	52.37559142	55.53119577;
7.50126602	11.73493580	15.26818135	18.63744289	21.93171490	25.18392549	28.40977625	31.61787561	34.81339286	37.99964079	41.17884934	44.35257909	47.52195679	50.68781767	53.85079452	57.01137597;
8.57783635	12.93238612	16.52936580	19.94185326	23.26805282	26.54503194	29.79074846	33.01517853	36.22438043	39.42227446	42.61152205	45.79399953	48.97107084	52.14375286	55.31282019	58.47887392;
9.64742151	14.11551883	17.77401226	21.22906251	24.58719737	27.88926930	31.15532646	34.39662844	37.62007793	40.83017857	44.03001022	47.22175835	50.40702087	53.58699532	56.76259837	59.93454420;
10.71143388	15.28673755	19.00459346	22.50139861	25.89127717	29.21856337	32.50524722	35.76379284	39.00190265	42.22463831	45.43548297	48.63692253	51.83078381	55.01844243	58.20095570	61.37915070;
11.77087655	16.44785262	20.22303132	23.76071579	27.18202141	30.53450459	33.84196565	37.11800029	40.37106880	43.60676479	46.82895933	50.04042886	53.24322313	56.43889194	59.62863120	62.81337953];

if M~=0     % M = 0 for K/Ka-band Fabry-Perot
rvac=a(1)+a(2)*Tvac+a(3)*Tvac^2;
rgas=a(1)+a(2)*Temperature+a(3)*Temperature^2;
rAr=a(1)+a(2)*TAr+a(3)*TAr^2;
hvac=b(1)+b(2)*Tvac;
hgas=b(1)+b(2)*Temperature;
hAr=b(1)+b(2)*TAr;
hvacP=hvac*(1+2*0.29*Pressure/1.93e6);
rvacP=rvac*(1-0.71*Pressure/1.93e6);
hvacPAr=hvac*(1+2*0.29*PAr/1.93e6);
rvacPAr=rvac*(1-0.71*PAr/1.93e6);


fvacTemp_theory=c*1e5/(2*pi).*sqrt((p(N+1,M)./rvac).^2+(L*pi./hvac).^2);
fgasTemp_theory=c*1e5/(2*pi).*sqrt((p(N+1,M)./rgas).^2+(L*pi./hgas).^2);
fArTemp_theory=c*1e5/(2*pi).*sqrt((p(N+1,M)./rAr).^2+(L*pi./hAr).^2);

fvacPres_theory=c*1e5/(2*pi).*sqrt((p(N+1,M)./rvacP).^2+(L*pi./hvacP).^2);
fvacPresAr_theory=c*1e5/(2*pi).*sqrt((p(N+1,M)./rvacPAr).^2+(L*pi./hvacPAr).^2);

fPTcorr=fvacPres_theory-fgasTemp_theory;
fPTcorrAr=fvacPres_theory-fArTemp_theory;

else
    fPTcorr=0;
    fPTcorrAr=0;

end


Tvac=Tvac+Tdifferential;
if M~=0
rvac=a(1)+a(2)*Tvac+a(3)*Tvac^2;
hvac=b(1)+b(2)*Tvac;
hvacP2=hvac*(1+2*0.29*Pressure/1.93e6);
rvacP2=rvac*(1-0.71*Pressure/1.93e6);

fPTcorr2=fvacPres_theory-fgasTemp_theory;
fPTcorrAr2=fvacPres_theory-fArTemp_theory;

else
    fPTcorr2=0;
    fPTcorrAr2=0;
end
Fgas=nh3PeakFa;
FAr=ArPeakFa;
fPTcorrsigma=abs(fPTcorr2-fPTcorr);
fPTcorrsigmaAr=abs(fPTcorrAr2-fPTcorrAr);

Fvac_sigma=sqrt(confc/sqrt(Gasnumswp)*((V1PeakFe/3)^2+(V2PeakFe/3)^2+(V3PeakFe/3)^2+sigma_o_vac^2));
Fvac_sigmaAr=sqrt(confc/sqrt(Gasnumswp)*((V1PeakFe/3)^2+(V2PeakFe/3)^2+(V3PeakFe/3)^2+sigma_o_vac^2));

Fgas_sigma=sqrt(nh3PeakFe^2+sigma_o_gas^2);
FAr_sigma=sqrt(ArPeakFe^2+sigma_o_gas^2);

Nmeasured=1e6*(Fvac-Fgas-fPTcorr)/Fgas;
Nmeasured_2sigma=1e6*sqrt(Fvac_sigma^2+Fgas_sigma^2+fPTcorrsigma^2)/Fgas; %95 confidence interval

NmeasuredAr=1e6*(Fvac-FAr-fPTcorrAr)/FAr;
NmeasuredAr_2sigma=1e6*sqrt(Fvac_sigma^2+FAr_sigma^2+fPTcorrsigmaAr^2)/FAr; %95 confidence interval
