function sigma_n=insterror(Ql,Qu,sl,su,Span,RBW,fol,fou,t_loaded,t_unloaded,BW,numswp,time,device)
%Error due to electrical noise and instrumentation uncertainity
%HP 8564E calibrated 12/5/05

%Courtesy of Priscilla Mohammed, modified for network analyzer by Tom Hanley

%Ql = Q loaded
%Qu = Q matched
%sl = Sample standard deviation of BW loaded readings in Hz
%su = Sample standard deviation of BW matched readings in Hz
%fol = Freq of loaded resonance Hz
%fou = Freq of matched resonance Hz
%t_loaded = Transmissivity loaded (linear)
%t_unloaded = Transmissivity matched (linear)
%BW = BW of loaded resonance Hz
%numswp = number of sweeps (for finding confidence coefficient)
%time = date of measurement
%device = device that took the data (0 for E5071C Network Analyzer [not obtained until 1/31/07], 1 for
%       8564E Spectrum Analyzer, 2 for 40 GHz Network Analyzer, 3 for E5071B Network Analyzer, borrowed 
%       from Dr. Durgin's lab prior to aquiring E5071C)

% critical values from t-table for 95% confidence 
if numswp==5
    confc=2.776;
elseif numswp==3
    confc=4.303;
elseif numswp==7
    confc=2.447;    
elseif numswp==10
    confc=2.262;
elseif numswp==30
    confc=2.045; 
end
    
sigma_nl_sqrd = (confc*(sl))^2/numswp; %Sigma loaded BW weighted by 95% confidence coefficient
sigma_nu_sqrd = (confc*(su))^2/numswp; %Sigma matched BW weighted by 95% confidence coefficient

lambda = 299792.458/fol;   %Wavelength of loaded resonance in km


% Use 95% confidence 
if device==1
yrs = etime(time,[2005 12 5 0 0 0])/(60*60*24*365.24); % years since 8564E spectrum analyzer calibrated (12/5/05)

    if fol < 6.4e9
        N=1;
    elseif fol < 13.2e9
        N=2;
    elseif fol < 31e9
        N=4;
    elseif fol < 40.05e9
        N=8;
    else
        N=18; % w-band harmonic mixer
    end

  %determine the least significant digit from the span measurement
    if Span < 1e4
        LSD=1;
    elseif Span < 1e5
        LSD=10;
    elseif Span < 1e6
        LSD=100;
    elseif Span < 1e7
        LSD=1e3;
    elseif Span < 1e8
        LSD=1e4;
    elseif Span < 1e9
        LSD=1e5;
    elseif Span < 1e10
        LSD=1e6;
    else
        LSD=1e7;
    end


sigma_delta = (BW*(yrs*1e-7+3.2e-8) + 4*N + 2*(LSD))*2/3; %Hz for HP8564E
if Span > 2e6*N
    sigma_o = ((yrs*1e-7+3.2e-8)*fol + .15*RBW + .05*Span + 10)*2/3; %Hz for HP8564E
else
    sigma_o = ((yrs*1e-7+3.2e-8)*fol + .15*RBW + .01*Span + 10)*2/3; %Hz for HP8564E
end
elseif device==0||device==2  % 40 GHz network analyzer used 10MHz frequency reference from E5071C
yrs = etime(time,[2007 1 7 0 0 0])/(60*60*24*365.24); % years since E5071C network analyzer calibrated (1/7/07)
sigma_delta = (BW*sqrt(2)*(5e-8+5e-7*yrs))*2/3; %Hz
sigma_o = fol*(5e-8+5e-7*yrs)*2/3;
elseif device==3
yrs = etime(time,[2005 6 1 0 0 0])/(60*60*24*365.24); % years since E5071B network analyzer calibrated (6/2005)
sigma_delta = (sqrt(2)*BW*(5e-6+5e-7*yrs))*2/3; %Hz
sigma_o = fol*(5e-6+5e-7*yrs)*2/3;
end


gamma_u = 1 - sqrt(t_unloaded);
gamma_l = 1 - sqrt(t_loaded);

A = (gamma_u^2)/(fou^2);
B = (sigma_o^2)/(Qu^2);
C = (2*sigma_o*sigma_delta)/Qu;
Gamma_u_sqrd = A*(B + sigma_delta^2 + sigma_nu_sqrd + C);

a = (gamma_l^2)/(fol^2);
b = (sigma_o^2)/(Ql^2);
c = (2*sigma_o*sigma_delta)/Ql;
Gamma_l_sqrd = a*(b + sigma_delta^2 + sigma_nl_sqrd + c);

D = -(gamma_u*gamma_l)/(fol*fou);
E = (sigma_o^2)/(Ql*Qu);
F = (sigma_o*sigma_delta)/Ql;
G = (sigma_o*sigma_delta)/Qu;
Gamma_u_Gamma_l = D*(E + sigma_delta^2 + F + G);

sigma_psi_sqrd = Gamma_u_sqrd + Gamma_l_sqrd - 2*(Gamma_u_Gamma_l);
sigma_n = (20*log10(exp(1))*pi/lambda*(sqrt(sigma_psi_sqrd))); %dB/km for 2-sigma uncertainty.